-- Companion
-- Added 2010-11-19 by Thomas Holden
-- Edited 2011-02-26 by Thomas Holden
-- Creates your companion, which shows your health and junk

companion = class:new()

function companion:init(id)
	self.id = id or 1
	self.flash = 1
	self.bucket_flash = 1
	if players[self.id].companion ~= "hide" then
		self.xList = {}
		for i=1, 8 do	-- fill up table with starting values
			self.xList[i] = 0
		end
		self.yList = {}
		for i=1, 6 do	-- y coords not as far behind
			self.yList[i] = 0
		end
	end
	for key, value in pairs(players[self.id].moves) do
		loadStaticImg("actors", "companion_"..key)
	end
	print("New companion ID " .. self.id .. " created")
end 

function companion:update(dt)
	if players[self.id].companion ~= "hide" then
		table.remove(self.xList, 1)	-- trim oldest entry
		table.remove(self.yList, 1)
		self.xList[#self.xList + 1], self.yList[#self.yList + 1] = ent.actor.avatar[self.id].body:getPosition()
	end
	if self.flash > 1 then
		self.flash = self.flash - dt
	end
	if self.bucket_flash > 1 then
		self.bucket_flash = self.bucket_flash - dt
	end
end

function companion:draw()
	local parent = players[self.id]
	if parent.companion ~= "hide" then
		local drawX = self.xList[1] - (20 * ent.actor.avatar[self.id].direction)		-- x is 8 frames behind the avatar
		local drawY = self.yList[1]
		local red, green, blue, alpha = love.graphics.getColor()
		if self.flash > 1 then
			green = 255 / self.flash
			blue = 255 / self.flash
		end
		local companionAlpha = (parent.health / (parent.max.health + 1)) * 255		-- companion fades as player takes damage
		love.graphics.setColor(red, green, blue, companionAlpha)
		love.graphics.draw(staticImg["companion_"..parent.companion], drawX, drawY, 0, ent.actor.avatar[self.id].direction, 1, 32, 32)
		-- draw the cooldown frill thingie
		local frills = 5 - math.ceil((parent.cooldown / parent.moves[parent.selected].cooldown) * 4)
		love.graphics.draw(staticImg.cooldown[frills], drawX, drawY, 0, ent.actor.avatar[self.id].direction, 1, 4, 32)
		-- draw the move this player has selected
		love.graphics.draw(staticImg["companion_"..parent.selected], drawX, drawY, 0, ent.actor.avatar[self.id].direction, 1, -6, 18)
		love.graphics.setColor(255, 255, 255, alpha)
	end
	if parent.bucket > 0 then
		local drawX = self.xList[1] - 16
		local drawY = self.yList[1] - 64
		local red, green, blue, alpha = love.graphics.getColor()
		if self.bucket_flash > 1 then
			red = 255 / self.bucket_flash
			blue = 255 / self.bucket_flash
		end
		love.graphics.setColor(red, green, blue, (parent.bucket * 2.5))
		love.graphics.draw(staticImg.bucket, drawX, drawY)
		love.graphics.setColor(255, 255, 255, alpha)
	end
end
