-- floater
-- Added 2010-12-11 by Thomas Holden
-- Edited 2011-02-27 by Thomas Holden
-- Creates an floating NPC animal

floater = class:new()

function floater:init(x, y, speed, range, resolve, buoyancy)
	self.id = 1
	self.name = "floater"
	self.width = 16
	self.height = 16
	self.startX = x
	self.startY = y
	self.speed = speed or 32
	self.range = range or 64
	self.resolve = resolve or 6		-- how often we change direction (in seconds)
	self.buoyancy = buoyancy or 240
	self:changeDirection()
	self.body = love.physics.newBody(world, x + 8, y + 8, 0.1)
	self.body:setLinearDamping(10)	-- this is a LOT, to make it floaty
	self.body:putToSleep()
	self.shape = love.physics.newRectangleShape(self.body, 0, 0, self.width, self.height)
	self.shape:setCategory(1)
	self.shape:setData(self)
	loadStaticImg("actors", "floater")
	printInit(self, x, y)
end 

function floater:update(dt)
	if self.body:isSleeping() then
		if self.body:getX() < (camera.x + screen.width) then	-- does not compensate for Y offset, but eh
			self.body:wakeUp()
		end
	else
		if not editor.state then
			self.countdown = self.countdown - dt
			if self.countdown <= 0 then
				self:changeDirection()
			end
			-- adjust directions so we don't exceed our range (Not sure if this actually works)
			local distanceX = self.body:getX() - self.startX
			local distanceY = self.body:getY() - self.startY
			local distance = math.sqrt(math.pow(distanceX, 2) + math.pow(distanceY, 2))
			if distance > self.range then
				if distanceX > self.range / 2 then
					self.xDirection = -self.xDirection
				end
				if distanceY > self.range / 2  then
					self.yDirection = -self.yDirection
				end
			end
			self.body:setLinearVelocity(self.speed*self.xDirection, self.speed*self.yDirection)
		end
		negateGravity(self.body)
	end
end

function floater:draw()
	local drawX = self.body:getX() - (self.width / 2)
	local drawY = self.body:getY() - (self.height / 2)
	if testOverlap(drawX,drawY,self.width,self.height) then
		love.graphics.draw(staticImg.floater, drawX, drawY)
	end
end

function floater:collide(shapeData)
	print("Floater ID " .. self.id .. " hit, changing direction")
	self:changeDirection()
end

function floater:changeDirection()
	self.countdown = math.random(self.resolve)	-- how long before we change next
	self.xDirection = math.random() - 0.5		-- offset by half to give us negatives
	self.yDirection = math.random() - 0.5
end

function floater:setHealth(number, cause)	-- this is mostly around to avoid bugs
	self:changeDirection()
end
