-- NPC
-- Added 2010-11-01 by Thomas Holden
-- Edited 2011-04-11 by Thomas Holden
-- Creates an NPC

npc = class:new()

function npc:init(x, y, dialog, responses, speed, range, buoyancy)
	self.id = 1
	self.name = "npc"
	self.startX = x
	self.startY = y
	self.width = 32
	self.height = 64
	self.dialog = dialog or "..."
	self.responses = responses or {{"OK."}, {[[dialog.state=false]]}}
	self.speed = speed or 8
	self.range = range or 128
	self.direction = -1
	self.wait = 0
	self.buoyancy = buoyancy or 240
	local mass = 1
	if editor.state then
		mass = 0
	end
	self.body = love.physics.newBody(world, x + 16, y + 32, mass)
	self.body:putToSleep()
	self.shape = love.physics.newRectangleShape(self.body, 0, 0, self.width, self.height)
	self.shape:setSensor(true)
	self.shape:setCategory(1)
	self.shape:setData(self)
	loadStaticImg("actors", "npc")
	printInit(self, x, y)
end 

function npc:update(dt)
	if self.wait > 0 then
		self.wait = self.wait - dt
	end
	if self.body:isSleeping() then
		local cullX = self.body:getX() - (self.width / 2)
		local cullY = self.body:getY() - (self.height / 2)
		if testOverlap(cullX, cullY, self.width, self.height) then
			self.body:wakeUp()
			self.body:setLinearVelocity(self.speed * self.direction, 0)
		end
	else
		self.body:setLinearVelocity(self.speed * self.direction, 0)
		if self.body:getX() < self.startX - self.range then
			self.direction = 1
		elseif self.body:getX() > self.startX + self.range then
			self.direction = -1
		end
		negateGravity(self.body)		-- FIX FOR BUG: npc that walks off of home terrain will start falling (due to sensor status?)
	end
end

function npc:draw()
	local drawX = self.body:getX() - (self.width / 2)
	local drawY = self.body:getY() - (self.height / 2)
	if testOverlap(drawX,drawY,self.width,self.height) then
		if self.direction > 0 then
			drawX = drawX + 32
		end
		love.graphics.draw(staticImg.npc, drawX, drawY, 0, -self.direction, 1)
	end
end

function npc:collide(shapeData)
	if shapeData.name == "avatar" and self.wait <= 0 and not editor.state then
		self.wait = 1	-- it takes a second for us to change our mind again
		dialog:setText(self.dialog, ((#self.responses[1] * 32) + 32))
		dialog:setResponses(self.responses)
		print("NPC ID " .. self.id .. " is talking")
	end
end

function npc:setHealth(number, cause)	-- this is mostly around to avoid bugs
	self.direction = -self.direction
end
