-- barrier
-- Added 2011-02-20 by Thomas Holden
-- Edited 2011-03-01 by Thomas Holden
-- Creates a barrier block

barrier = class:new()

function barrier:init(x, y, height, angle, visible, key)
	self.id = 1
	self.name = "barrier"
	self.width = 16
	self.height = height or 64
	self.angle = angle or 0			-- in degrees
	self.visible = visible ~= false
	key = key or {"will", 1}
	self.key = {
		category = key[1],
		number = key[2]	
	}
	self.body = love.physics.newBody(world, x + (self.width / 2), y + (self.height / 2), 0)
	self.shape = love.physics.newRectangleShape(self.body, 0, 0, self.width, self.height)
	self.body:setAngle(math.rad(self.angle))
	self.shape:setCategory(4)
	self.shape:setData(self)
	self.live = true
	loadStaticImg("world", "barrier")
	loadStaticImg("world", "barrier_cap")
	print("New barrier ID " .. self.id .. " created")
end

function barrier:update(dt)
	-- nothing much
end

function barrier:draw()
	if self.visible or editLens then
		local cullX = self.body:getX() - (self.width / 2)
		local cullY = self.body:getY() - (self.height / 2)
		if testOverlap(cullX, cullY, self.width, self.height) then
			local offsetX = self.width / 2
			local offsetY = (self.height / 2)
			love.graphics.draw(staticImg.barrier, self.body:getX(), self.body:getY(), math.rad(self.angle), 1, ((self.height - 32) / 16), offsetX, 8)
			love.graphics.draw(staticImg.barrier_cap, self.body:getX(), self.body:getY(), math.rad(self.angle), 1, 1, offsetX, offsetY)
			love.graphics.draw(staticImg.barrier_cap, self.body:getX(), self.body:getY(), math.rad(self.angle + 180), 1, 1, offsetX, offsetY)
		end
	end
end

function barrier:collide(shapeData)
	if shapeData.name == "avatar" and not editor.state then
		local text = "This barrier needs "..self.key.number.." "..self.key.category.." pickups to open."
		local responses = {
			{
				"Done.", 
				"I'll come back later."
			},
			{
				"ent.geometry.barrier["..self.id.."]:open("..shapeData.id..")",
				"dialog.state=false"
			}
		}
		dialog:setText(text, 96)
		dialog:setResponses(responses)
	end
end

function barrier:open(who)
	if players[who].items[self.key.category] >= self.key.number then
		print("barrier ID "..self.id.." opening")
		players[who].items[self.key.category] = players[who].items[self.key.category] - self.key.number
		self.live = false
		physicsRemoval(self)
	end
	dialog.state = false
end
