-- blockMaker
-- Added 2010-11-01 by Thomas Holden
-- Edited 2011-03-04 by Thomas Holden
-- The blockMaker starts out as a single block, which when hit creates a series of madeblocks

blockMaker = class:new()

function blockMaker:init(x, y, xchange, ychange, interval, blocksLeft)
	self.id = 1
	self.name = "blockMaker"
	self.width = 32
	self.height = 32
	self.change = {
		x = xchange or 64,
		y = ychange or 0
	}
	self.interval = interval or 32		-- affected by change in x and y... consider rewrite
	self.blocksLeft = blocksLeft or 32
	self.live = true
	self.body = love.physics.newBody(world, x + 16, y + 16)
	self.shape = love.physics.newRectangleShape(self.body, 0, 0, self.width, self.height)
	self.shape:setCategory(4)
	self.shape:setData(self)
	loadStaticImg("world", "blockmaker")
	printInit(self, x, y)
end

function blockMaker:update(dt)
	if self.madeBlock then
		if self.blocksLeft > 0 then
			local newX = self.body:getX() + (self.change.x * dt)
			local newY = self.body:getY() + (self.change.y * dt)
			self.distance.x = self.distance.x + (self.change.x * dt)
			self.distance.y = self.distance.y + (self.change.y * dt)
			self.body:setPosition(newX, newY)
			if (self.distance.x > self.interval) or (self.distance.y > self.interval) then
				newX = math.floor(newX) - 16
				newY = math.floor(newY) - 16
				self.madeBlock[#self.madeBlock + 1] = madeBlock:new((#self.madeBlock + 1), newX, newY)
				self.distance.x = self.distance.x - self.interval
				self.distance.y = self.distance.y - self.interval
				self.blocksLeft = self.blocksLeft - 1
			end
		else
			self:destroy()
		end
	end
end

function blockMaker:draw()
	if self.madeBlock then
		for i=1, #self.madeBlock do
			self.madeBlock[i]:draw()
		end
	end
	if self.live then
		local drawX = self.body:getX() - (self.width / 2)
		local drawY = self.body:getY() - (self.height / 2)
		if testOverlap(drawX,drawY,self.width,self.height) then
			love.graphics.draw(staticImg.blockmaker, drawX, drawY)
		end
	end
end

function blockMaker:collide(shapeData)
	if not self.madeBlock then
		self.madeBlock = {
			madeBlock:new(1, self.body:getX() - 16, self.body:getY() - 16)
		}
		self.distance = {x = 0, y = 0}
		print("blockMaker ID " .. self.id .. " is starting to make blocks")
	end
end

function blockMaker:destroy()
	if self.live then
		self.live = false
		physicsRemoval(self)
		print("blockMaker ID " .. self.id .. " destroyed")
	end
end
