-- breakable
-- Added 2010-11-01 by Thomas Holden
-- Edited 2011-04-15 by Thomas Holden
-- Creates a breakable block

breakable = class:new()

function breakable:init(x, y, width, height, units, visible)
	self.id = 1
	self.name = "breakable"
	local multiplier = units or 32
	self.width = (width or 1) * multiplier
	self.height = (height or 1) * multiplier
	self.visible = visible ~= false
	self.body = love.physics.newBody(world, x + (self.width / 2), y + (self.height / 2), 0)
	self.shape = love.physics.newRectangleShape(self.body, 0, 0, 32, 32)
	self.shape:setCategory(4)
	self.shape:setData(self)
	loadStaticImg("world", "breakable")
	loadStaticImg("world", "broken")
	printInit(self, x, y)
end

function breakable:update(dt)
	-- nothing much
end

function breakable:draw()
	if self.visible or editLens then
		if self.broken_bit then
			for i=1, 4 do
				local drawX = self.broken_bit[i].body:getX() - 8
				local drawY = self.broken_bit[i].body:getY() - 8
				love.graphics.draw(staticImg.broken, drawX, drawY, self.broken_bit[i].body:getAngle())
			end
		else
			local drawX = self.body:getX() - (self.width / 2)
			local drawY = self.body:getY() - (self.height / 2)
			if testOverlap(drawX,drawY,self.width,self.height) then
				for i=1, self.width, 32 do		-- width must fit evenly into 32, or problems happen
					for j=1, self.height, 32 do	-- height must fit evenly into 32, or problems happen
						love.graphics.draw(staticImg.breakable, drawX + i - 1, drawY + j - 1)
					end
				end
			end
		end
	end
end

function breakable:collide(shapeData)
	if shapeData.name == "avatar" and not editor.state then
		if shapeData.body:getY() > self.body:getY() + 12 then	-- there are a few pixels leeway here
			sfx:play("crunch")
			self:killAbove(shapeData)
			self:explode()
		end
	end
end

function breakable:killAbove(cause)
	for i=1, #ent.actor.baddie do
		local target = ent.actor.baddie[i]
		local theirX, theirY = target.body:getPosition()
		local myX, myY = self.body:getPosition()
		if testOverlap(myX,(myY-self.height),self.width,self.height, theirX,theirY,target.width,target.height) then
			target:setHealth(-3, cause)
		end
	end
end

function breakable:explode()
	print("Breakable exploding")
	-- add four small bits
	self.broken_bit = {}
	local newX = self.body:getX() - 8
	local newY = self.body:getY() - 8
	local velX = -25
	local velY = -100
	for i=1, 4 do
		self.broken_bit[i] = {}
		if i == 2 then		-- second bit goes up and right
			newX = newX + 32
			velX = 25
		elseif i == 3 then	-- third bit goes straight left
			newY = newY + 32
			velX = -100
			velY = -5
		elseif i == 4 then	-- fourth bit goes straight right
			newX = newX + 32
			newY = newY + 32
			velX = 100
			velY = -5
		end
		self.broken_bit[i].body = love.physics.newBody(world, newX, newY, 100)
		self.broken_bit[i].body:setAngularVelocity(5*-(i%2))	-- negative spin if on left, positive if on right
		self.broken_bit[i].body:setLinearVelocity(velX, velY)
		self.broken_bit[i].shape = love.physics.newRectangleShape(self.broken_bit[i].body, 0, 0, 16, 16)
		self.broken_bit[i].shape:setMask(1,2,3,4)
	end
	physicsRemoval(self)
end
