-- platform
-- Added 2010-12-27 by Thomas Holden
-- Edited 2011-03-04 by Thomas Holden
-- Creates a moving platform

platform = class:new() 

function platform:init(x, y, goalX, goalY, speed, mode)
	self.id = 1
	self.name = "platform"
	self.width = 128
	self.height = 16
	self.start = {
		x = x,
		y = y
	}
	self.goal = {
		x = goalX or (x + 256),
		y = goalY or y
	}
	speed = speed or 16
	self.speed = {
		x = (self.goal.x - x) / speed,
		y = (self.goal.y - y) / speed
	}
	self.mode = mode or "repeat"
	self.body = love.physics.newBody(world, x + 64, y + 8, 1000)
	self.shape = love.physics.newRectangleShape(self.body, 0, 0, 128, 16)
	self.shape:setCategory(4)
	self.shape:setData(self)
	loadStaticImg("world", "platform")
	printInit(self, x, y)
end

function platform:update(dt)
	self.body:setLinearVelocity(self.speed.x, self.speed.y)
	negateGravity(self.body)
	local newX = self.body:getX() - (self.width / 2)
	local newY = self.body:getY() - (self.height / 2)
	if	(self.speed.x > 0 and newX >= self.goal.x) or
		(self.speed.x < 0 and newX <= self.start.x) or
		(self.speed.y > 0 and newY >= self.goal.y) or
		(self.speed.y < 0 and newY <= self.start.y)
	then
		if self.mode == "repeat" then
			self.body:setPosition(self.start.x, self.start.y)
			print("Platform ID " .. self.id .. " reseting position")
		else
			self.speed.x = -self.speed.x
			self.speed.y = -self.speed.y
			print("Platform ID " .. self.id .. " changing direction")
		end
	end
end

function platform:draw()
	local drawX = self.body:getX() - (self.width / 2)
	local drawY = self.body:getY() - (self.height / 2)
	if testOverlap(drawX,drawY,self.width,self.height) then
		love.graphics.draw(staticImg.platform, drawX, drawY)
	end
end

