-- water
-- Added 2010-11-01 by Thomas Holden
-- Edited 2011-02-28 by Thomas Holden
-- Creates a water rectangle

water = class:new()	

function water:init(x, y, width, height, units, visible)
	self.id = 1
	self.name = "water"
	local multiplier = units or 32
	self.width = (width or 2) * multiplier
	self.height = (height or 2) * multiplier
	self.visible = visible ~= false
	self.body = love.physics.newBody(world, x + (self.width / 2), y + (self.height / 2), 0)
	self:makeShape()
	self.imageSize = makeImage(self.width, self.height, self.name)
	printInit(self, x, y)
end

function water:update(dt)
	-- not much
end

function water:draw()
	if self.visible or editLens then
		local drawX = self.body:getX() - (self.width / 2)
		local drawY = self.body:getY() - (self.height / 2)
		if testOverlap(drawX,drawY,self.width,self.height) then
			love.graphics.draw(generatedImg.water[self.imageSize], drawX, drawY)
		end
	end
end

function water:collide(shapeData)
	if shapeData.buoyancy and shapeData.buoyancy > 0 then
		shapeData.swimming = true
		print("Ent is swimming")
	end
end

function water:persist(shapeData)
	if shapeData.buoyancy and shapeData.buoyancy > 0 then
		-- special thanks to ghostwriter for water physics help
		local velX, velY = shapeData.body:getLinearVelocity()
		local distanceSubmerged = (self.body:getY() - (self.height / 2)) - (shapeData.body:getY() + (shapeData.height / 2))
		local fractionSubmerged = -distanceSubmerged / shapeData.height
		velX = (-velX / 3)
		velY = (-velY / 2) - (shapeData.buoyancy * math.min(1, fractionSubmerged)) -- cannot be more than 100% submerged
		shapeData.body:applyForce(velX, velY)
	end
end

function water:remove(shapeData)
	if shapeData.buoyancy and shapeData.buoyancy > 0 then
		shapeData.swimming = false
	end
end

function water:makeShape()
	if self.shape then
		self.shape:destroy()
	end
	self.shape = love.physics.newRectangleShape(self.body, 0, 0, self.width, self.height)
	self.shape:setSensor(true)
	self.shape:setCategory(4)
	self.shape:setData(self)
	print("Water shape completed")
end
