-- bomb
-- Added 2011-01-06 by Thomas Holden
-- Edited 2011-03-04 by Thomas Holden
-- Creates a bomb (and the explosion afterwards)

bomb = class:new() 

function bomb:init(id, x, y, xdirection, ydirection, strength, countdown, duration)
	self.id = id or 1	-- the parent
	self.name = "bomb"
	self.width = 24
	self.height = 24
	self.xdirection = xdirection or 32
	self.ydirection = ydirection or -64
	self.strength = strength or 1
	self.countdown = countdown or 3		-- how long before the blast
	self.duration = duration or 5		-- how long the blast lasts
	self.detonated = false
	self.live = true
	self.body = love.physics.newBody(world, x + 12, y + 12, 8)
	self.body:applyImpulse(self.xdirection, self.ydirection)
	self.body:applyTorque(20)
	self:makeShape(12, false)
	loadStaticImg("effects", "bomb")
	loadStaticImg("effects", "explosion")
end

function bomb:update(dt)
	if not self.detonated then
		self.countdown = self.countdown - dt	-- count down to detonation
		if self.countdown <= 0 then
			self:detonate()
		end
	else
		if self.live then
			self.duration = self.duration - dt
			if self.duration <= 0 then
				self:destroy()
			end
		end
	end
end

function bomb:draw()
	if self.live then
		local drawX = self.body:getX()
		local drawY = self.body:getY()
		if not self.detonated then
			love.graphics.draw(staticImg.bomb, drawX, drawY, self.body:getAngle(), .75, .75, 12, 12)
		else
			love.graphics.setColor(255, 255, 255, math.min((self.duration * 50), 255))
			love.graphics.draw(staticImg.explosion, drawX, drawY, 0, 1, 1, 64, 64)
			setDefaultColor()
		end
	end
end

function bomb:collide(shapeData)
	if self.detonated and self.live then
		print("Type Hit: "..shapeData.name)
		if shapeData.name == "avatar" and shapeData.id ~= self.id then
			players[shapeData.id]:setHealth(-self.strength, self)
		elseif shapeData.name == "baddie" or shapeData.name == "boss" then
			shapeData:setHealth(-self.strength, self)
		end
	end
end

function bomb:makeShape(radius, sensorness)
	if self.shape then
		self.shape:destroy()
	end
	self.shape = love.physics.newCircleShape(self.body, 0, 0, (radius or 12))
	self.shape:setSensor(sensorness or false)
	self.shape:setCategory(2)
	local size = (radius or 12) * 2
	self.shape:setData(self)
end

function bomb:detonate()
	self.detonated = true
	self.body:setMass(0,0,0,0)
	self:makeShape(64, true)
	camera:shake(2,2,2)
	sfx:play("crunch")
	print("Bomb detonated")
end

function bomb:destroy()
	self.live = false
	physicsRemoval(self)
	print("Bomb destroyed")
end
