-- boomerang
-- Added 2011-01-07 by Thomas Holden
-- Edited 2011-03-04 by Thomas Holden
-- Creates a boomerang

boomerang = class:new() 

function boomerang:init(id, x, y, xdirection, ydirection, strength, range)
	self.id = id or 1	-- the parent
	self.name = "boomerang"
	self.width = 24
	self.height = 24
	self.start = {
		x = x + 12,
		y = y + 12
	}
	self.direction = {
		x = xdirection or 256,
		y = ydirection or 0
	}
	self.strength = strength or 1
	self.range = range or 256
	self.reversed = false
	self.live = true
	self.angle = 0
	self.body = love.physics.newBody(world, x + 12, y + 12, 100)
	self.shape = love.physics.newCircleShape(self.body, 0, 0, 12)
	self.shape:setSensor(true)
	self.shape:setCategory(2)
	self.shape:setData(self)
	loadStaticImg("effects", "boomerang")
end

function boomerang:update(dt)
	if self.live then
		local hDistance = math.abs(self.start.x - self.body:getX())
		local vDistance = math.abs(self.start.y - self.body:getY())
		if self.reversed then
			if hDistance < math.abs(self.direction.x / 10) or vDistance < math.abs(self.direction.y / 10) then
				self:destroy()
				return
			end
		else
			if hDistance >= self.range or vDistance >= self.range or self.body:getX() < 1 or self.body:getY() < 1 then
				self:reverse()
			end
		end
		self.body:setLinearVelocity(self.direction.x, self.direction.y)
		negateGravity(self.body)
		self.angle = rotateImage(self.angle, (dt * 2))
	end
end

function boomerang:draw()
	if self.live then
		local drawX = self.body:getX()
		local drawY = self.body:getY()
		love.graphics.draw(staticImg.boomerang, drawX, drawY, math.rad(self.angle), .5, .5, 24, 24)
	end
end

function boomerang:collide(shapeData)
	if self.live then
		print("Type Hit: "..shapeData.name)
		if shapeData.name == "avatar" and shapeData.id ~= self.id then
			players[shapeData.id]:setHealth(-self.strength, self)
			self:reverse()
		elseif shapeData.name == "baddie" or shapeData.name == "boss" then
			shapeData:setHealth(-self.strength, self)
			self:reverse()
		end
	end
end

function boomerang:reverse()
	if not self.reversed then
		self.reversed = true
		self.direction.x = -self.direction.x
		self.direction.y = -self.direction.y
		print("Boomerang reversed")
	end
end

function boomerang:destroy()
	self.live = false
	physicsRemoval(self)
	print("Boomerang destroyed")
end
