-- lightning
-- Added 2010-11-06 by Thomas Holden
-- Edited 2011-03-04 by Thomas Holden
-- Creates a lightning bolt

lightning = class:new() 

function lightning:init(id, x, y, direction, strength, speed)
	self.id = id or 1	-- the parent, used to avoid shooting self
	self.name = "lightning"
	self.width = 64
	self.height = 16
	self.direction = direction or 1
	self.strength = strength or 1
	self.speed = speed or 720
	self.live = true
	self.body = love.physics.newBody(world, x + 32, y + 8, 100)
	self.shape = love.physics.newRectangleShape(self.body, 0, 0, self.width, self.height)
	self.shape:setSensor(true)
	self.shape:setCategory(2)
	self.shape:setData(self)
	loadStaticImg("effects", "lightning")
end

function lightning:update(dt)
	if self.live then
		self.body:setLinearVelocity(self.direction * self.speed, 0)
		negateGravity(self.body)
	end
end

function lightning:draw()
	if self.live then
		love.graphics.draw(staticImg.lightning, self.body:getX(), self.body:getY(), 0, self.direction, 1, 32, 8)
	end
end

function lightning:collide(shapeData)
	if self.live then
		print("Type Hit: "..shapeData.name)
		if shapeData.name == "avatar" and shapeData.id ~= self.id then
			players[shapeData.id]:setHealth(-self.strength, self)
			self:detonate(true)
		elseif shapeData.name == "baddie" or shapeData.name == "boss" then
			shapeData:setHealth(-self.strength, self)
			self:detonate(true)
		elseif shapeData.name == "npc" or shapeData.name == "signpost" or shapeData.name == "home" then
			-- pass through
		else 	-- its probably geometry, so fizzle out
			self:detonate(false)
		end
	end
end

function lightning:detonate(boom)
	if boom then
		camera:shake(1,1,1)
		sfx:play("lightning")
	end
	self.live = false
	physicsRemoval(self)
	print("Lightning detonated")
end
