-- home
-- Added 2011-01-24 by Thomas Holden
-- Edited 2011-02-26 by Thomas Holden
-- Creates a home that propels the player

home = class:new() 

function home:init(x, y, targets, visible)
	self.id = 1
	self.name = "home"
	self.width = 64
	self.height = 64
	self.targets = targets or {64, 160, 256, 352}
	self.visible = visible ~= false
	self.alpha = 250
	self.alpha_change = -64
	self.body = love.physics.newBody(world, x + 32, y + 32, 0)
	self.shape = love.physics.newRectangleShape(self.body, 0, 0, self.width, self.height)
	self.shape:setSensor(true)
	self.shape:setCategory(3)
	self.shape:setData(self)
	loadStaticImg("world", "home")
	printInit(self, x, y)
end

function home:update(dt)
	self.alpha, self.alpha_change = pulsateAlpha(self.alpha, self.alpha_change, dt)
end

function home:draw()
	if self.visible or editLens then
		local drawX = self.body:getX() - (self.width / 2)
		local drawY = self.body:getY() - (self.height / 2)
		if testOverlap(drawX, drawY, self.width, self.height) then
			love.graphics.setColor(255, 255, 255, self.alpha)
			love.graphics.draw(staticImg.home, drawX, drawY)
			setDefaultColor()
		end
	end
end

function home:collide(shapeData)
	if shapeData.name == "avatar" and (gamemode == "singleplayer" or gamemode == "coop") then
		self:updateTargets(shapeData.id)
	end
end

function home:persist(shapeData)
	if shapeData.name == "avatar" and players[shapeData.id].bucket > 0 then		-- include code to check team? nah...
		local ceiled_value = math.ceil(players[shapeData.id].bucket)
		print("Increasing score by " .. ceiled_value)
		local which = shapeData.id
		if gamemode == "team_capture" then
			which = players[shapeData.id].team
		end
		scene.score[which] = scene.score[which] + ceiled_value
		players[shapeData.id].history.score = players[shapeData.id].history.score + ceiled_value
		players[shapeData.id].bucket = 0
	end
end

function home:updateTargets(who)
	who = who or 1
	for i=1, #ent.sensor.home do
		ent.sensor.home[i].targets[who] = false
	end
	self.targets[who] = (64 * who) - 64
	print("Targets updated for player " .. who)
end
