-- pickup
-- Added 2010-11-01 by Thomas Holden
-- Edited 2011-03-04 by Thomas Holden
-- Creates a pickupable item

pickup = class:new() 

function pickup:init(x, y, category, dropped)
	self.id = 1
	self.name = "pickup"
	self.width = 32
	self.height = 32
	self.category = category or "attack"
	self.dropped = dropped or 0
	self.live = true
	self.alpha = 255
	self.alpha_change = -128
	self.body = love.physics.newBody(world, x + 16, y + 16, self.dropped)
	self.shape = love.physics.newRectangleShape(self.body, 0, 0, self.width, self.height)
	self.shape:setCategory(3)
	if self.dropped > 0 then
		self.body:applyImpulse(0, -8)
	else
		self.shape:setSensor(true)
	end
	self.shape:setData(self)
	loadStaticImg("pickups", "pickup_"..self.category)
	printInit(self, x, y)
end

function pickup:update(dt)
	if self.live then
		self.alpha, self.alpha_change = pulsateAlpha(self.alpha, self.alpha_change, dt)
	end
end

function pickup:draw()
	if self.live then
		local cullX = self.body:getX() - (self.width / 2)
		local cullY = self.body:getY() - (self.height / 2)
		if testOverlap(cullX, cullY, self.width, self.height) then
			love.graphics.setColor(255, 255, 255, self.alpha)
			-- pickups images are 2x size
			love.graphics.draw(staticImg["pickup_"..self.category], self.body:getX(), self.body:getY(), 0, .5, .5, self.width, self.height)
			setDefaultColor()
		end
	end
end

function pickup:collide(shapeData)
	if shapeData.name == "avatar" and self.live and not editor.state then
		players[shapeData.id].items[self.category] = players[shapeData.id].items[self.category] + 1
		self.live = false
		physicsRemoval(self)
		sfx:play("pickup")
		print("Pickup " .. self.id .. " collected by player " .. shapeData.id)
	end
end
