-- spring
-- Added 2010-12-19 by Thomas Holden
-- Edited 2011-02-26 by Thomas Holden
-- Creates a spring that propels the player

spring = class:new() 

function spring:init(x, y, xForce, yForce)
	self.id = 1
	self.name = "spring"
	self.width = 32
	self.height = 32
	self.xForce = xForce or 0		-- no horizontal thrust
	self.yForce = yForce or -64		-- light upwards thrust
	self.body = love.physics.newBody(world, x + 16, y + 16, 0)
	self.shape = love.physics.newRectangleShape(self.body, 0, 0, self.width, self.height)
	self.shape:setSensor(true)
	self.shape:setCategory(3)
	self.shape:setData(self)
	loadStaticImg("world", "spring_base")
	loadStaticImg("world", "spring_wave")
	self.wave_alpha = 255
	self.wave_position = 0
	printInit(self, x, y)
end

function spring:update(dt)
	if self.wave_alpha > 0 then
		self.wave_alpha = self.wave_alpha - (128 * dt)
		self.wave_position = self.wave_position - (self.yForce * dt)
	else
		self.wave_alpha = 255
		self.wave_position = 0
	end
end

function spring:draw()
	local drawX = self.body:getX() - (self.width / 2)
	local drawY = self.body:getY() - (self.height / 2)
	if testOverlap(drawX,drawY,self.width,self.height) then
		love.graphics.setColor(255, 255, 255, self.wave_alpha)
		love.graphics.draw(staticImg.spring_wave, drawX, drawY, 0, 1, 1, 0, self.wave_position)
		setDefaultColor()
		love.graphics.draw(staticImg.spring_base, drawX, drawY)
	end
end

function spring:collide(shapeData)
	shapeData.body:applyImpulse(self.xForce, self.yForce)
	print("Spring force of " .. self.xForce .. " by " .. self.yForce .. " applied to " .. shapeData.name .. " ID " .. shapeData.id)
end
