-- teleport
-- Added 2010-12-20 by Thomas Holden
-- Edited 2011-02-26 by Thomas Holden
-- Creates a teleporter (which can preserve or even multiply momentum)

teleport = class:new() 

function teleport:init(x, y, xDestination, yDestination, momentum, visible)
	self.id = 1
	self.name = "teleport"
	self.width = 32
	self.height = 32
	self.xDestination = xDestination or 0
	self.yDestination = yDestination or 0
	self.momentum = momentum or 1	-- how much we multiply momentum
	self.visible = visible ~= false
	self.alpha = 255
	self.alpha_change = -128
	self.body = love.physics.newBody(world, x + 16, y + 16, 0)
	self.shape = love.physics.newRectangleShape(self.body, 0, 0, self.width, self.height)
	self.shape:setSensor(true)
	self.shape:setCategory(3)
	self.shape:setData(self)
	loadStaticImg("pickups", "teleport")
	printInit(self, x, y)
end

function teleport:update(dt)
	if self.visible then
		self.alpha, self.alpha_change = pulsateAlpha(self.alpha, self.alpha_change, dt)
	end
end

function teleport:draw()
	if self.visible or editLens then
		local drawX = self.body:getX() - (self.width / 2)
		local drawY = self.body:getY() - (self.height / 2)
		if testOverlap(drawX, drawY, self.width, self.height) then
			love.graphics.setColor(255, 255, 255, self.alpha)
			love.graphics.draw(staticImg.teleport, drawX, drawY, 0, 1, 1, 16, 16)	-- teleport img has 16px of padding
			setDefaultColor()
		end
		if editor.state and editor.brush == "teleport" and editor.select == self.id then 
			love.graphics.print("* Teleport Destination", self.xDestination, self.yDestination)
		end
	end
end

function teleport:collide(shapeData)
	local xVel, yVel = shapeData.body:getLinearVelocity()
	shapeData.body:setX(self.xDestination)
	shapeData.body:setY(self.yDestination)
	shapeData.body:setLinearVelocity(xVel * self.momentum, yVel * self.momentum)
	print(shapeData.name .. " ID " .. shapeData.id .. " teleported to " .. self.xDestination .. " by " .. self.yDestination)
end
