-- Main
-- Added 2010-11-01 by Thomas Holden
-- Edited 2011-04-11 by Thomas Holden
-- Creates the entire engine, contains the most general functions, and starts up the intro

function love.run()
	love.load(arg)
	local dt = 0
	while true do
		-- Update
		love.timer.step()
		dt = love.timer.getDelta()
		love.update(dt)
		-- Render
		love.graphics.clear()
		love.draw()
		-- Process events
		for e,a,b,c in love.event.poll() do
			if e == "q" then
				if not love.quit or not love.quit() then
					love.audio.stop()
					return
				end
			end
			love.handlers[e](a,b,c)
		end
		love.timer.sleep(1)	-- 1000 FPS max
		love.graphics.present()
	end
end

function love.load()
	require "subclass/class.lua"
	require "subclass/utils.lua"
	gameversion = 110415	-- define the game version, (theoretically) used for checking level versions etc
	defaultVideoSettings()
	defaultSoundSettings()
	if love._version >= 071 then		-- we have to be running at least love 0.7.1 to play
		require "scenes/intro.lua"		-- ready the next scene
		scene = intro:new()		-- the scene is what gets called into action, whether that be the intro, game, whatever...
	else
		require "scenes/nogo.lua"
		scene = nogo:new()
	end
end

function love.update(dt)
	dt = math.min(dt, .5)	-- prevent overly large dt values
	scene:update(dt)
end

function love.draw()
	scene:draw()
end

function love.keypressed(key, unicode)
	scene:keypressed(key, unicode)
end

--[[
function love.keyreleased(key)
	if scene.keyreleased then
		scene:keyreleased(key)
	end
end

function love.mousepressed(x, y, button)
	if scene.mousepressed then
		scene:mousepressed(x, y, button)
	end
end
--]]

function love.mousereleased(x, y, button)
	if scene.mousereleased then		-- largely unused, hence the check
		scene:mousereleased(x, y, button)
	end
end

function love.joystickpressed(joystick, button)
	if scene.keypressed then
		scene:joystickpressed(joystick, button)
	end
end

function love.focus(f)
	if scene.focus then
		scene:focus(f)
	end
end
