-- How To
-- Added 2011-01-16 by Thomas Holden
-- Edited 2011-02-26 by Thomas Holden
-- Walks through gameplay

howto = class:new()

function howto:init(slide)
	currentScene = "howto"
	-- fade in from black
	fader:start(255, -128)
	-- load theme music
	music:play("theme")
	-- some scene specific variables
	self.slide = slide or 1
	self.index = {
		"About",
		"Abilities",
		"Multiplayer",
		"Editing"
	}
	self.fadeout = false
	print("Howto scene initiated")
end

function howto:update(dt)
	if self.fadeout then
		if fader.finished then
			self.slide = self.slide + 1
			self.fadeout = false
			fader:start(255, -196)
		end
	end
	fader:update(dt)
end

function howto:draw()
	love.graphics.printf(self.index[self.slide], 0, 8, screen.width, "center")
	love.graphics.printf("Page "..self.slide.." of "..#self.index, 0, screen.height - 32, screen.width, "center")
	if self.slide == 1 then
		love.graphics.printf(string.gsub([[
			Kurosuke is a sidescrolling platformer. By default, you play by using the arrow keys and two action buttons.
			The action buttons are ]]..keyWord(bindings[1][5])..[[ and ]]..keyWord(bindings[1][6])..[[. The first allows you to attack, and the second lets you cycle though your available attacks.
			When you first start playing, the only attack available will be your Lunge attack. This doesn't do any damage (yet), but it does give you a running start.
			]], "\t\t\t", "\n"), 8, 48, screen.width - 16, "left")
	elseif self.slide == 2 then
		love.graphics.printf(string.gsub([[
			The lunge, your default attack, is useful for dodging and getting a running start, but there are several other attacks that you can unlock through the course of the game.
			Lightning bolts are a reliable offensive move, travelling quickly enough to do damage before most opponents can react.
			Bombs are less direct but open up the possibilites of striking multiple opponents at once, as well as letting you avoid exposing yourself by dropping them from above.
			The boomerang is a defensive weapon, allowing the player to control an area while retreating.
			]], "\t\t\t", "\n"), 8, 48, screen.width - 16, "left")
	elseif self.slide == 3 then
		love.graphics.printf(string.gsub([[
			Kurosuke is not limited to singleplayer. You can play with up to four people at once, in Coop or Versus modes.
			It is important to note that in singleplayer, there is a very limited number of powerups available. Cooperate to maximize your effectiveness.
			In Versus, players compete to collect tokens before the others. You are given multiple weapons that allow you to do so!
			]], "\t\t\t", "\n"), 8, 48, screen.width - 16, "left")
	elseif self.slide == 4 then
		love.graphics.printf(string.gsub([[
			Editing maps in Kurosuke can be done largely done via the keypad or WASD. Hitting KP5 or Spacebar will add a new object to the map you're in. 
			Using the KP+ and KP- keys, or Tab and Shift, you can change the object you have selected. Using KP* and KP/ or F and R you can change the brush you have selected. Using KP0 or Ctrl will change the brush set you have selected.
			Editing can also be done via the mouse. Click anywhere on the screen to create an object there, automatically aligned to a 32 pixel grid.
			Scroll to change your brush selection. Right click to select an object from your current brush set. Middle click to swap brush sets. 
			Hit left-shift to change your modifier. The modifier modifies how much objects move or are scaled. 
			To save your map, hit the pause button (]]..bindings[1][7]..[[, ]]..bindings[2][7]..[[, ]]..bindings[3][7]..[[, or ]]..bindings[4][7]..[[) and choose Save Level.
			]], "\t\t\t", "\n"), 8, 48, screen.width - 16, "left")
	end
	fader:draw()
end

function howto:keypressed(key, unicode)
	local playerNum, keyNum = checkBindings(key)
	if keyNum == 6 then		-- a player's back key
		if self.slide <= 1 then
			self:finish()
		else
			self.slide = self.slide - 1
		end
	elseif keyNum == 7 then
		self:finish()
	else
		self:proceed()
	end
end

function howto:joystickpressed(stick, button)
	self:keypressed("j"..stick.."_b"..button)
end

function howto:proceed()
	if self.slide < #self.index then
		self.fadeout = true
		fader:start(0, 196)
	else 
		self:finish()
	end
end

function howto:finish()
	scene = menu:new()
end