-- Character Select
-- Added 2010-11-18 by Thomas Holden
-- Edited 2011-04-15 by Thomas Holden
-- Creates the players array

require "subclass/player.lua"
require "scenes/game.lua"
select = class:new()

function select:init()
	currentScene = "select"
	fader:start(255, -128)
	self.heads = {
		elk = newPaddedImage("media/images/actors/elk-head.png"),
		puma = newPaddedImage("media/images/actors/puma-head.png"),
		wolf = newPaddedImage("media/images/actors/wolf-head.png"),
		hare = newPaddedImage("media/images/actors/hare-head.png")
	}
	self.allready = multiplayer
	self.ready = {}
	players = {}	-- make sure the table is empty
	for i=1, multiplayer do
		self.ready[i] = false
		self:createPlayer(i)
	end
	-- load up the player save data
	if saveData ~= "" then
		applyPlayerSave()
	end
	if editor.state then
		players[1].companion = "hide"	-- this keeps the companion from rendering at all
		self.allready = 0	-- jump to the game object on first update
	end
	loadStaticImg("actors", "companion_fish")
	loadStaticImg("actors", "companion_rune")
	print("Select scene initiated")
end

function select:update(dt)
	fader:update(dt)
	if self.allready == 0 then
		scene = game:new()
	end
end

function select:draw()
	love.graphics.printf("Select Your Avatar And Companion:", 0, 128, screen.width, "center")
	for i=1, multiplayer do
		local columnX = (screen.width / (multiplayer + 1)) * i		-- player heads are equidistant from each other and the screen edges
		local columnY = screen.halfHeight - 128
		love.graphics.printf("Player " .. i, (columnX - 64), columnY, 128, "center")
		love.graphics.draw(self.heads[players[i].species], (columnX - 16), columnY + 32)
		local controls = keyWord(players[i].key.up) .. "\n"
		controls = controls .. keyWord(players[i].key.left) .. "   " .. keyWord(players[i].key.right) .. "\n"
		controls = controls .. keyWord(players[i].key.down)
		love.graphics.printf(controls, (columnX - 64), (columnY + 96), 128, "center")
		love.graphics.draw(staticImg["companion_" .. players[i].companion], (columnX - 32), (columnY + 176))
		local readymessage = "Ready!"
		if not self.ready[i] then
			readymessage = "Hit " .. keyWord(players[i].key.attack) .. " when ready."
		end
		love.graphics.printf(readymessage, (columnX - 64), (columnY + 224), 128, "center")
	end
	if multiplayer < 4 then	
		local addplayer = "Press " .. keyWord(bindings[multiplayer + 1][5]) .. " to join."
		love.graphics.printf(addplayer, 0, screen.halfHeight + 256, screen.width, "center")
	end
	fader:draw()
	if showFPS then
		love.graphics.print(love.timer.getFPS(), screen.width - 32, screen.height - 24)
	end
end

function select:keypressed(key, unicode)
	if key == "return" then		-- extra binding for single players in a rush
		self.allready = self.allready - 1
		self.ready[1] = true
	end
	local playerNum, keyNum = checkBindings(key)
	if keyNum == 1 or keyNum == 2 then		-- up/down
		self:changeCompanion(playerNum)
	elseif keyNum == 3 then					-- left
		self:changeSpecies(playerNum, false)
	elseif keyNum == 4 then					-- right
		self:changeSpecies(playerNum, true)
	elseif keyNum == 5 then					-- atk button
		if multiplayer < playerNum and multiplayer > playerNum - 2 then		-- check that this is the next player supposed to join
			multiplayer = playerNum
			self:createPlayer(playerNum)
			self.ready[playerNum] = false
			self.allready = self.allready + 1
		else
			self.ready[playerNum] = true
			self.allready = self.allready - 1
		end
	elseif keyNum == 6 then					-- action button
		self.ready[playerNum] = false
	elseif keyNum == 7 then					-- pause button
		if self.allready < multiplayer then
			self.allready = multiplayer
			for i=1, multiplayer do
				self.ready[i] = false
			end
		else
			scene = menu:new()
		end
	end
end

function select:joystickpressed(stick, button)
	self:keypressed("j"..stick.."_b"..button)
end

function select:createPlayer(number)
	local who = number or 1
	local team = 1
	if (gamemode == "team_versus" or gamemode == "team_capture") then
		team = math.abs((who % 2) - 2)
	end
	local species = {"elk", "puma", "wolf", "hare"}
	local companions = {"fish", "rune"}
	-- player (id, keys (up, down, left, right, attack, action), species, companion, team)
	players[who] = player:new(who, bindings[who], species[who], companions[team], team)
	print("Player " .. who .. " created on team " .. team)
end

function select:changeSpecies(who, dir)
	who = who or 1
	dir = dir or true
	local list = {"elk", "puma", "wolf", "hare"}
	if dir then
		players[who].species = nextInList(players[who].species, list)
	else
		players[who].species = prevInList(players[who].species, list)
	end
	print("Species changed for player " .. who .. " to " .. players[who].species)
end

function select:changeCompanion(number)
	local who = number or 1
	players[who].companion = nextInList(players[who].companion, {"fish", "rune"})
	print("Companion changed for player " .. who .. " to " .. players[who].companion)
end
