-- Menu List
-- Added 2011-01-12 by Thomas Holden
-- Edited 2011-04-11 by Thomas Holden
-- creates and manages a menu list, complete with pointer

menuList = class:new()

function menuList:init(x, y)
	self.x = x or 0
	self.y = (y or 0) - 32
	self.bg = false
	self.gui = {
		text = {},
		commands = {},
		selected = 1,
		key = "top",
	}
	self.history = {}
	self.rebind = {}
	self:repopulate()
	loadStaticImg("gui", "menu_foot")
	loadStaticImg("gui", "menu_tile")
	loadStaticImg("gui", "menu_top")
	loadStaticImg("logos", "kurosuke_pause")
	print("MenuList created")
end 

function menuList:update(dt)
	menuPointer:update(dt)
end

function menuList:draw()
	if self.bg then
		love.graphics.draw(staticImg.menu_top, self.x, self.y - 64)
		for i=-1, #self.gui.text do		-- we need two extras that the pause logo will go over
			love.graphics.draw(staticImg.menu_tile, self.x, self.y + (32 * i))
		end
		love.graphics.draw(staticImg.kurosuke_pause, self.x, self.y - 48)
		love.graphics.draw(staticImg.menu_foot, self.x, self.y + (32 * #self.gui.text) + 32)
	end
	for i=1, #self.gui.text do
		if i == self.gui.selected then
			love.graphics.setColor(240, 240, 240, 255)
		else
			setDefaultColor()
		end
		love.graphics.print(self.gui.text[i], self.x + 64, self.y + (32 * i))
	end
	menuPointer:draw()
end

function menuList:keypressed(key, unicode)
	local playerNum, keyNum = checkBindings(key)
	if #self.rebind >= 2 then
		if playerNum == 0 and keyNum == 0 then
			bindings[self.rebind[1]][self.rebind[2]] = key
			self.rebind = {self.rebind[1]}
			self.gui.key = "bind_list"
		else
			self.rebind = {self.rebind[1]}
			self.gui.key = "key_taken"
		end
		self:repopulate()
	else
		if keyNum == 1 then		-- usually up key
			self:moveCursor(-1)
		elseif keyNum == 2 then	-- usually down key
			self:moveCursor(1)
		elseif keyNum == 3 then	-- usually left key
			if players[playerNum] then
				players[playerNum].viewstats.page = players[playerNum].viewstats.page - 1
				if players[playerNum].viewstats.page < 1 then
					players[playerNum].viewstats.page = 3
				end
			end
		elseif keyNum == 4 then	-- usually right key
			if players[playerNum] then
				players[playerNum].viewstats.page = players[playerNum].viewstats.page + 1
				if players[playerNum].viewstats.page > 3 then
					players[playerNum].viewstats.page = 1
				end
			end
		elseif key == "return" or keyNum == 5 then
			local commands = loadstring(self.gui.commands[self.gui.selected])
			commands()	-- execute the code that was stored in the commands table
			sfx:play("confirm")
		elseif keyNum == 6 or keyNum == 7 then
			self:goBack()
		end
		menuPointer.yChange = self.gui.selected * 32
	end
end

function menuList:goBack(number)
	print("Going back a menu level")
	number = number or 1
	if self.gui.key == "top" then
		if currentScene == "menu" then
			love.event.push('q')	-- quit the game
		else
			scene.pause = false
		end
	else	-- escape up a level
		self.gui.key = self.history[#self.history - 1]
		for i=1, number do
			table.remove(self.history)	-- remove last entry
		end
		self:repopulate()
		sfx:play("back")
	end
end

function menuList:moveCursor(direction)
	print("Moving menu cursor")
	direction = direction or 1
	self.gui.selected = self.gui.selected + direction
	if self.gui.selected < 1 then
		self.gui.selected = #self.gui.text
	elseif self.gui.selected > #self.gui.text then
		self.gui.selected = 1
	end
	if self.gui.text[self.gui.selected] == " " then		-- skip blank lines
		self:moveCursor(direction)
	end
end

function menuList:reposition(x, y)
	print("Repositioning menulist")
	self.x = x or 0
	self.y = (y or 0) - 32
	-- repositioning also resets the intra-menu position
	self.gui.selected = 1
	self.gui.key = "top"
	self:repopulate()
	menuPointer.x = self.x + 32
	menuPointer.y = self.y - 4
	menuPointer.yChange = 32
end

function menuList:repopulate(keep_place)
	keep_place = keep_place or false
	local key = self.gui.key
	local text = self.gui.text[key]
	if self.history[#self.history] ~= key then
		self.history[#self.history + 1] = key
	end
	self.gui.text = {}
	self.gui.commands = {}
	local recur = [[ ]]		-- if there is some recurring code it gets stored in this
	local add_back = true	-- the back button, almost always present
	local add_options = false	-- additions option controls
	if key == "top" then
		recur = [[
			menuList:repopulate()
		]]
		if currentScene == "game" then
			self:insert("Resume Game", [[
				scene.pause = false
			]])
			if editor.state then
				self:insert("Save Level", [[
					if currentLevel ~= "new" then
						saver:saveLevel()
					else
						saver:saveNewLevel()
					end
					menuList.gui.key = "success"
				]] .. recur)
			else
				self:insert("Player Stats", [[
					menuList.gui.key = "stats_menu"
				]] .. recur)
				self:insert("Save Game", [[
					menuList.gui.key = "save_menu"
				]] .. recur)
			end
		else
			self:insert("Singleplayer", [[
				multiplayer = 1
				gamemode = "singleplayer"
				editor.state = false
				menuList.gui.key = "level_select"
			]] .. recur)
			self:insert("Multiplayer", [[
				multiplayer = 2
				editor.state = false
				menuList.gui.key = "mode_select"
			]] .. recur)
			self:insert("Editor", [[
				multiplayer = 1
				gamemode = "singleplayer"
				editor:startup()
				menuList.gui.key = "editor"
			]] .. recur)
		end
		self:insert("Options", [[
			menuList.gui.key = "main_options"
		]] .. recur)
		self:insert("How To Play", [[
			menuList.gui.key = "how_to_play"
		]] .. recur)
		if currentScene == "game" then
			self:insert("Quit to Menu", [[
				scene.pause = false
				music:stop()
				music:play("theme")
				scene = menu:new()
			]])
		end
		self:insert("Quit Game", [[
			love.event.push('q')
		]])
		add_back = false
	elseif key == "level_select" then
		if gamemode == "singleplayer" and love.filesystem.exists("saves") then
			self:insert("Load Save Data",[[
				menuList.gui.key = "load_saves"
				menuList:repopulate()
			]])
		end
		local filesTable = listFiles('levels')
		for k, v in pairs(filesTable) do 
			self:insert(v, [[
				currentLevel = spacesToUnderscores(menuList.gui.text[menuList.gui.selected])
				scene = select:new()
			]])
		end
	elseif key == "load_saves" then
		local filesTable = listFiles('saves')
		for k, v in pairs(filesTable) do 
			self:insert(v, [[
				saveData = "saves/"..spacesToUnderscores(menuList.gui.text[menuList.gui.selected])..".lua"	-- deformat name for later use
				love.filesystem.load(saveData)()	-- loads/executes the code that was in the save file
				scene = select:new()
			]])
		end
	elseif key == "mode_select" then
		recur = [[
			menuList.gui.key = "level_select"
			menuList:repopulate()
		]]
		self:insert("Coop", [[
			gamemode = "coop"
		]] .. recur)
		self:insert("Versus", [[
			gamemode = "versus"
		]] .. recur)
		self:insert("Team Versus", [[
			gamemode = "team_versus"
		]] .. recur)
		self:insert("Capture", [[
			gamemode = "capture"
		]] .. recur)
		self:insert("Team Capture", [[
			gamemode = "team_capture"
		]] .. recur)
	elseif key == "editor" then
		self:insert("Create New Level",[[
			currentLevel = "new"
			scene = select:new()
		]])
		local filesTable = listFiles('userlevels')
		for k, v in pairs(filesTable) do 
			self:insert(v, [[
				currentLevel = spacesToUnderscores(menuList.gui.text[menuList.gui.selected])
				scene = select:new()
			]])
		end
	elseif key == "main_options" then
		recur = [[
			menuList:repopulate()
		]]
		self:insert("Video Options", [[
			menuList.gui.key = "video_options"
		]] .. recur)
		self:insert("Sound Options", [[
			menuList.gui.key = "sound_options"
		]] .. recur)
		self:insert("Input Options", [[
			menuList.gui.key = "input_options"
		]] .. recur)
		self:insert("Misc Options", [[
			menuList.gui.key = "misc_options"
		]] .. recur)
		add_options = true
	elseif key == "video_options" then
		recur = [[
			reloadGraphics()
		]]
		self:insert("Toggle Full Screen", [[
			screen.fullscreen = not screen.fullscreen
		]] .. recur)
		self:insert("Increase Screen Width", [[
			screen.width = screen.width + 32
		]] .. recur)
		self:insert("Decrease Screen Width", [[
			screen.width = screen.width - 32
		]] .. recur)
		self:insert("Increase Screen Height", [[
			screen.height = screen.height + 32
		]] .. recur)
		self:insert("Decrease Screen Height", [[
			screen.height = screen.height - 32
		]] .. recur)
		add_options = true
	elseif key == "sound_options" then
		recur = [[
			menuList:repopulate(true)
		]]
		self:insert("Raise Master (" .. round(volume.master, 2) * 100 .. ")", [[
			if volume.master < 1 then
				volume.master = love.audio.getVolume() + .1
				love.audio.setVolume(volume.master)
			end
		]] .. recur)
		self:insert("Lower Master", [[
			if volume.master > 0 then
				volume.master = love.audio.getVolume() - .1
				love.audio.setVolume(volume.master)
			end
		]] .. recur)
		self:insert("Raise Music (" .. round(volume.music, 2) * 100 .. ")", [[
			if volume.music < 1 then
				music:changeVolume(.1)
			end
		]] .. recur)
		self:insert("Lower Music", [[
			if volume.music > 0 then
				music:changeVolume(-.1)
			end
		]] .. recur)
		self:insert("Raise Sound FX (" .. round(volume.sfx, 2) * 100 .. ")", [[
			if volume.sfx < 1 then
				sfx:changeVolume(.1)
			end
		]] .. recur)
		self:insert("Lower Sound FX", [[
			if volume.sfx > 0 then
				sfx:changeVolume(-.1)
			end
		]] .. recur)
		add_options = true
	elseif key == "input_options" then
		for i=1,4 do
			self:insert("Rebind Player "..i.." Keys", [[
				menuList.rebind = {]]..i..[[}
				menuList.gui.key = "bind_list"
				menuList:repopulate()
			]])
		end
		add_options = true
	elseif key == "bind_list" then
		table.remove(menuList.history)
		local heading = {"Up", "Down", "Left", "Right", "Attack", "Action", "Pause"}
		for i=1, 7 do
			self:insert(heading[i] .. ":   "..keyWord(bindings[self.rebind[1]][i]), [[
				menuList.rebind[2] = ]] .. i .. [[
				menuList.gui.key = "press_any_key"
				menuList:repopulate()
			]])
		end
	elseif key == "press_any_key" then
		table.remove(menuList.history)
		self:insert("Press Any Key")
		add_back = false
	elseif key == "key_taken" then
		self:insert("That key is already taken.", [[
			menuList:goBack(2)
		]])
	elseif key == "misc_options" then
		self:insert("Toggle FPS Counter", [[
			showFPS = not showFPS
			reloadGraphics()
		]])
		self:insert("Toggle Edit Help", [[
			editHelp = not editHelp
		]])
		self:insert("Toggle Edit Lens", [[
			editLens = not editLens
		]])
		add_options = true
	elseif key == "stats_menu" then
		self:insert("Hit left / right to page")
		self:insert(" ")
		self:insert("Level: "..currentLevel)
		local mode = underscoresToSpaces(gamemode)
		self:insert("Mode: "..mode)
		local minutes = round((love.timer.getTime() - start_time) / 60, 1)
		self:insert("Play time: "..minutes.." min")
		self:insert(" ")
	elseif key == "save_menu" then
		self:insert("New Save Data", [[ 
			saver:saveNewFile()
			menuList:repopulate()
		]])
		local filesTable = listFiles('saves')
		local i = 1
		for key, value in pairs(filesTable) do 
			self:insert(value, [[
				saver:saveFile(]]..i..[[)
			]])
			i = i + 1
		end
	elseif key == "success" then
		self:insert("Success!")
	elseif key == "how_to_play" then
		self:insert("View the Full Tutorial", [[ 
			scene = howto:new()
		]])
		self:insert("View Editor Help", [[ 
			scene = howto:new(4)
		]])
	end
	-- extremely common menu functionality
	if add_options then
		recur = [[
			menuList.gui.key = menuList.history[#menuList.history-1]
			table.remove(menuList.history)	-- remove last two entries
			table.remove(menuList.history)
			menuList:repopulate()
		]]
		self:insert("Reset Options", [[
			if menuList.gui.key == "main_options" or menuList.gui.key == "video_options" then
				defaultVideoSettings()
				reloadGraphics()
			end
			if menuList.gui.key == "main_options" or menuList.gui.key == "sound_options" then
				defaultSoundSettings()
				love.audio.setVolume(volume.master)
			end
			if menuList.gui.key == "main_options" or menuList.gui.key == "input_options" then
				bindings = getDefaultBindings()
			end
		]] .. recur)
		self:insert("Save Options", [[
			saver:saveOptions()
		]] .. recur)
	end
	if add_back then
		self:insert("Back", [[
			menuList:goBack(2)
		]])
	end
	if not keep_place then
		self.gui.selected = 1
	end
end

function menuList:insert(guistring, luastring)
	table.insert(self.gui.text, guistring or " ")
	table.insert(self.gui.commands, luastring or [[ ]])
end
