-- Saver
-- Added 2010-11-18 by Thomas Holden
-- Edited 2011-04-11 by Thomas Holden
-- helps save data

saver = class:new() 

function saver:init()
	-- not much
end

function saver:saveNewFile()
	print("Saving new file")
	if not love.filesystem.exists("saves") then
		love.filesystem.mkdir("saves")
	end
	saver:saveFile()
end

function saver:saveFile(savenumber)
	print("Saving file")
	savenumber = savenumber or (countFiles('saves') + 1)
	local file = love.filesystem.newFile("saves/save_"..savenumber..".lua")
	local saveData = self:prepSaveData()
	file:open('w')
	local madeFile = file:write(saveData)
	file:close()
end

function saver:saveOptions()
	print("Saving options")
	local settingsData = saver.prepSettingsData()
	local file = love.filesystem.newFile("settings.lua")
	file:open('w')
	file:write(settingsData)
	file:close()
end

function saver:saveNewLevel()
	print("Saving new level")
	if not love.filesystem.exists("userlevels") then
		love.filesystem.mkdir("userlevels")
	end
	local levelcount = 0
	for i,file in pairs(love.filesystem.enumerate('userlevels')) do
		if file:find('%.lua$') then
			levelcount = levelcount + 1
		end
	end
	currentLevel = "user_level_"..(levelcount + 1)
	self:saveLevel()
end

function saver:saveLevel()
	print("Saving level")
	local levelData = self:prepNewLevelData()
	local file = love.filesystem.newFile("userlevels/"..currentLevel..".lua")
	file:open('w')
	file:write(levelData)
	file:close()
end

function saver:prepSettingsData()
	print("Prepping settings data")
	local set = ""
	set = set .. "-- Save File\n"
	set = set .. "-- Created on " .. os.date("%c") .. "\n\n"
	set = set .. "settingsversion = " .. gameversion .. "\n"
	set = set .. "screen = {\n"
	set = set .. "	width = " .. screen.width .. ",\n"
	set = set .. "	height = " .. screen.height .. ",\n"
	set = set .. "	fullscreen = " .. toText(screen.fullscreen) .. ",\n"
	set = set .. "	vsync = " .. toText(screen.vsync) .. ",\n"
	set = set .. "	fsaa = " .. screen.fsaa .. "\n"
	set = set .. "}\n"
	set = set .. "showFPS = " .. toText(showFPS) .. "\n"
	set = set .. "editHelp = " .. toText(editHelp) .. "\n"
	set = set .. "editLens = " .. toText(editLens) .. "\n"
	set = set .. "bindings = {\n"
	for i=1, #bindings do
		if i > 1 then
			set = set .. ",\n"
		end
		set = set .. "	{ "
		for j=1, #bindings[i] do
			if j > 1 then
				set = set .. ", "
			end
			set = set .. "\"" .. bindings[i][j].. "\""
		end
		set = set .. " }"
	end
	set = set .. "\n}\n"
	set = set .. "volume = {\n"
	set = set .. "	master = " .. round(volume.master, 2) .. ",\n"
	set = set .. "	music = " .. round(volume.music, 2) .. ",\n"
	set = set .. "	sfx = " .. round(volume.sfx, 2) .. "\n"
	set = set .. "}\n"
	return set
end

function saver:prepSaveData()
	print("Prepping save data")
	local save = ""
	save = save .. "-- Save File\n"
	save = save .. "-- Created on " .. os.date("%c") .. "\n\n"
	save = save .. "saveversion = " .. gameversion .. "\n"
	save = save .. "currentLevel = \"" .. currentLevel .. "\"\n"
	save = save .. "\n"
	save = save .. "function applyPlayerSave()\n"
	for i=1, multiplayer do
		save = save .. "	players[" .. i .. "].species = \"" .. players[i].species .. "\"\n"
		save = save .. "	players[" .. i .. "].companion = \"" .. players[i].companion .. "\"\n"
		local toSave = {"history", "max", "items"}
		for j=1, #toSave do
			save = save .. "	players[" .. i .. "]." .. toSave[j] .. " = {\n"
			local first = true
			for key, value in pairs(players[i][toSave[j]]) do
				if not first then
					save = save .. ",\n"
				else
					first = false
				end
				save = save .. "		" .. key .. " = " .. value
			end
			save = save .. "\n	}\n"
		end
		save = save .. "	players[" .. i .. "].moves = {\n"
		local movelist = {"lunge", "lightning", "bomb", "boomerang"}
		for j=1, #movelist do
			save = save .. "		" .. movelist[j] .. " = {\n"
			local first = true
			for key, value in pairs(players[i].moves[movelist[j]]) do
				if not first then
					save = save .. ",\n"
				else
					first = false
				end
				save = save .. "			" .. key .. " = " .. value
			end
			save = save .. "\n		}"
			if j < #movelist then
				save = save .. ",\n"
			end
		end
		save = save .. "\n	}\n"
	end
	save = save .. "end\n"
	return save
end

function saver:prepNewLevelData()
	print("Prepping new level data")
	local lvl = ""
	lvl = lvl .. "-- User Level\n"
	lvl = lvl .. "-- Created on " .. os.date("%c") .. "\n\n"
	lvl = lvl .. "levelversion = " .. gameversion .. "\n"
	lvl = lvl .. "killdepth = " .. killdepth .. "\n"
	lvl = lvl .. "song = \"" .. song .. "\"\n\n"
	local worldSections = {"geometry", "sensor", "actor"}
	for i=1, #worldSections do
		local section = ent[worldSections[i]]
		for key, value in pairs(section) do
			if #section[key] > 0 and key ~= "avatar" and key ~= "companion" then
				lvl = lvl .. "ent." .. tostring(worldSections[i]).."."..key.." = {\n"
				for j=1, #section[key] do
					if j > 1 then
						lvl = lvl .. ",\n"
					end
					if worldSections[i] == "geometry" then
						lvl = lvl .. self:outputGeometryInit(key, ent.geometry[key][j])
					elseif worldSections[i] == "sensor" then
						lvl = lvl .. self:outputSensorInit(key, ent.sensor[key][j])
					elseif worldSections[i] == "actor" then
						lvl = lvl .. self:outputActorInit(key, ent.actor[key][j])
					end
				end
				lvl = lvl .. "\n}\n\n"
			end
		end
	end
	return lvl
end

function saver:outputGeometryInit(key, target)
	print("Outputting Geometry: " .. key)
	local out = "	" .. key .. ":new("
	if key == "nonsolid" or key == "ramp" then
		out = out .. toText(target.x) .. ", "
		out = out .. toText(target.y) .. ", "
	else
		out = out .. toText(target.body:getX() - (target.width / 2)) .. ", "
		out = out .. toText(target.body:getY() - (target.height / 2)) .. ", "
	end
	if testStrings(key, {"terrain", "water", "solidBlock", "breakable", "clip"}) then
		out = out .. toText(target.width / 32) .. ", "
		out = out .. toText(target.height / 32) .. ", "
		out = out .. "32, "
		out = out .. toText(target.visible)
	elseif key == "barrier" then
		out = out .. toText(target.height) .. ", "
		out = out .. toText(target.angle) .. ", "
		out = out .. toText(target.visible) .. ", "
		out = out .. "{\"" .. toText(target.key.category) .. "\", " .. toText(target.key.number) .. "}"
	elseif key == "blockMaker" then
		out = out .. toText(target.change.x) .. ", "
		out = out .. toText(target.change.y) .. ", "
		out = out .. toText(target.interval) .. ", "
		out = out .. toText(target.blocksLeft)
	elseif key == "crate" then
		out = out .. toText(target.mass) .. ", "
		out = out .. toText(target.inertia) .. ", "
		out = out .. toText(target.body:getAngle())
	elseif key == "nonsolid" then
		out = out .. toText(target.width) .. ", "
		out = out .. toText(target.height) .. ", "
		out = out .. "\"" .. toText(target.imageString) .. "\", "
		out = out .. toText(target.imgWidth) .. ", "
		out = out .. toText(target.imgHeight)
	elseif key == "platform" then
		out = out .. toText(target.goalX) .. ", "
		out = out .. toText(target.goalY) .. ", "
		out = out .. toText(target.speed) .. ", "
		out = out .. toText(target.mode)
	elseif key == "ramp" then
		out = out .. toText(target.width) .. ", "
		out = out .. toText(target.height) .. ", "
		out = out .. toText(target.direction) .. ", "
		out = out .. "32, "
		out = out .. toText(target.visible)
	elseif key == "spikes" then
		out = out .. toText(target.width / 32) .. ", "
		out = out .. toText(target.height / 32) .. ", "
		out = out .. "32, "
		out = out .. toText(target.angle) .. ", "
		out = out .. toText(target.strength)
	elseif key == "wellspring" then
		out = out .. toText(target.speed)
	end
	out = out .. ")"
	return out
end

function saver:outputSensorInit(key, target)
	print("Outputting Sensor: " .. key)
	local out = "	" .. key .. ":new("
	out = out .. toText(target.body:getX() - (target.width / 2)) .. ", "
	out = out .. toText(target.body:getY() - (target.width / 2)) .. ", "
	if testStrings(key, {"pickup", "charge", "unlock"}) then
		out = out .. "\"" .. toText(target.category) .. "\""
	end
	if key == "unlock" then
		out = out .. ", " .. toText(target.value)
	elseif key == "eol" then
		out = out .. "\"" .. toText(target.target) .. "\""
	elseif key == "home" then
		out = out .. "{"
		for i=1, 4 do
			if i > 1 then
				out = out .. ", "
			end
			out = out .. toText(target.targets[i])
		end
		out = out .. "}, "
		out = out .. toText(target.visible)
	elseif key == "teleport" then
		out = out .. toText(target.xDestination) .. ", "
		out = out .. toText(target.yDestination) .. ", "
		out = out .. toText(target.value) .. ", "
		out = out .. toText(target.visible)
	elseif key == "spring" then
		out = out .. toText(target.xForce) .. ", "
		out = out .. toText(target.yForce)
	end
	out = out .. ")"
	return out
end

function saver:outputActorInit(key, target)
	print("Outputting Actor: " .. key)
	local out = "	" .. key .. ":new("
	out = out .. toText(target.body:getX() - (target.width / 2)) .. ", "
	out = out .. toText(target.body:getY() - (target.height / 2)) .. ", "
	if key == "baddie" or key == "boss" then
		out = out .. toText(target.width) .. ", "
		out = out .. toText(target.height) .. ", "
		out = out .. "\"" .. toText(target.species) .. "\", "
		out = out .. "{" .. toText(target.stats.speed) .. ", "
		out = out .. toText(target.stats.strength) .. ", "
		out = out .. toText(target.stats.health) .. "}, "
		out = out .. "\"" .. toText(target.drop) .. "\", "
		out = out .. toText(target.motion.buoyancy) .. ", "
		out = out .. toText(target.anim:getSize()) .. ", "
		out = out .. toText(target.anim:getSpeed())
	elseif key == "npc" then
		out = out .. "\"" .. toText(target.dialog) .. "\", "
		out = out .. toText(target.speed) .. ", "
		out = out .. toText(target.range) .. ", "
		out = out .. toText(target.buoyancy)
	elseif key == "signpost" then
		out = out .. "\"" .. toText(target.dialog) .. "\", "
		out = out .. toText(target.dialogWidth - 128)
	elseif key == "floater" then
		out = out .. toText(target.speed) .. ", "
		out = out .. toText(target.range) .. ", "
		out = out .. toText(target.resolve) .. ", "
		out = out .. toText(target.buoyancy)
	end
	out = out .. ")"
	return out
end
