-- startup
-- Added 2010-12-18 by Thomas Holden
-- Edited 2011-04-15 by Thomas Holden
-- Creates a bunch of top-level variables at the start of the game

-- animation sheets 
animSheet = {}

-- static images
staticImg = {}
staticImg.cooldown = {}		-- load in cooldown images used by avatars
for i=0, 4 do
	staticImg.cooldown[i+1] = newPaddedImage("media/images/actors/cooldown_"..i..".png")
end

-- generated images
generatedImg = {
	terrain = {},
	water = {},
	ramp = {}
}

-- load in subclasses
require "subclass/AnAL.lua"
require "subclass/menulist.lua"
require "subclass/menupointer.lua"
require "subclass/camera.lua"
require "subclass/dialog.lua"
require "subclass/editor.lua"
require "subclass/fader.lua"
require "subclass/joystick.lua"
require "subclass/music.lua"
require "subclass/saver.lua"
require "subclass/sfx.lua"

camera = camera:new()
dialog = dialog:new()
editor = editor:new()
fader = fader:new()
joystick = joystick:new()
menuList = menuList:new()
menuPointer = menuPointer:new()
music = music:new()
saver = saver:new()
sfx = sfx:new()

defaultVideoSettings()	-- sets screen width and stuff

-- game variables
start_time = love.timer.getTime()
currentScene = "intro"
currentLevel = "level_1"
multiplayer = 1
gamemode = "singleplayer"	-- can also be "coop", "versus", "team_versus", "capture", "team_capture", "edit" mode
saveData = ""
players = {}
bindings = getDefaultBindings()
killdepth = 16000	-- die if fall below here

math.randomseed(os.time())

--initial graphics setup
love.mouse.setVisible(false)
love.graphics.setBackgroundColor(0, 0, 0)
gameIcon = newPaddedImage("media/images/logos/kurosuke_icon.png")
love.graphics.setIcon(gameIcon)

-- load up game font
gameFont = love.graphics.newFont("media/fonts/Aerofoil.ttf", 18)
love.graphics.setFont(gameFont)

-- settings
love.filesystem.setIdentity("kurosuke")			-- name of our save folder
if love.filesystem.exists("settings.lua") then	-- check for a settings config file
	love.filesystem.load("settings.lua")()		-- execute the settings in it
end

reloadGraphics()
love.audio.setVolume(volume.master)
